local metadata = {
"## Interface:FS17 1.4.4",
"## Title: animalCover",
"## Notes: See lua notes.",
"## Author: GTX MODS",
"## Version: 1.0",
"## Date: 02.04.2017",
"## Web: http://www.gtxmods.com/"
}

--[[

Credits:
animalCover.lua by GTX MODS    -    Based on Original cover.lua by Giants Software.

History:
V 1.0 @ 02.04.2017 - Initial Release by GTX MODS
V 1.1 @ 22.04.2017 - Added Auto Mode by GTX MODS

Free to use and edit but please keep credits and update Version Number and descriptions. If edited, send us a copy we would love to see it > http://www.gtxmods.com/contact-us/ 

Designed to be used on the CRT Animal Trailers. If used in Auto mode it forces the roof and windows open when animals are loaded and auto closes all when trailer is empty. 

EXAMPLE FOR XML:
<animalCover animationName="toggleCover" autoOpenClose="true"/>

]]

animalCover = {};

function animalCover.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function animalCover:preLoad(savegame)
    self.getIsToggleCoverAllowed = animalCover.getIsToggleCoverAllowed;
    self.allowFillType = Utils.overwrittenFunction(self.allowFillType, animalCover.allowFillType);
    self.getAllowFillFromAir = Utils.overwrittenFunction(self.getAllowFillFromAir, animalCover.getAllowFillFromAir);
    self.setCoverState = animalCover.setCoverState;
end;

function animalCover:load(savegame)
	self.isAnyUnitFilled = animalCover.isAnyUnitFilled
    -- self.addFillTrigger = Utils.overwrittenFunction(self.addFillTrigger, animalCover.addFillTrigger);
    -- self.removeFillTrigger = Utils.overwrittenFunction(self.removeFillTrigger, animalCover.removeFillTrigger);
    self.coverAnimation = getXMLString(self.xmlFile, "vehicle.animalCover#animationName");
    if self.coverAnimation ~= nil then
        local isOpen = Utils.getNoNil(getXMLBool(self.xmlFile, "vehicle.animalCover#openOnBuy"), false);
        if savegame ~= nil then
            isOpen = Utils.getNoNil(getXMLBool(savegame.xmlFile, savegame.key.."#isCoverOpen"), isOpen);
        end;
        self:setCoverState(isOpen, true);
        self.forceOpenOnTip = Utils.getNoNil(getXMLBool(self.xmlFile, "vehicle.animalCover#forceOpenOnTip"), true);
		self.autoOpenClose = Utils.getNoNil(getXMLBool(self.xmlFile, "vehicle.animalCover#autoOpenClose"), true);
    else
        self.isCoverOpen = true;
    end;	
end;

function animalCover:getSaveAttributesAndNodes(nodeIdent)
    if self.coverAnimation ~= nil then
        local attributes = 'isCoverOpen="'..tostring(self.isCoverOpen)..'"';
        return attributes, nil;
    end;
    return nil;
end;

function animalCover:readStream(streamId, connection)
    if connection:getIsServer() then
        if self.coverAnimation ~= nil then
            local isOpen = streamReadBool(streamId);
            self:setCoverState(isOpen, true);
        end;
    end;
end;

function animalCover:writeStream(streamId, connection)
    if not connection:getIsServer() then
        if self.coverAnimation ~= nil then
            streamWriteBool(streamId, self.isCoverOpen);
        end;
    end;
end;

function animalCover:update(dt)
	if self.coverAnimation ~= nil then
	local hasAnimals = self:isAnyUnitFilled() and self.autoOpenClose
		if self.autoOpenClose == false then
		else
		if hasAnimals then
				self:setCoverState(true);
			else
				self:setCoverState(false);
			end;
		end;
		if self:getIsActiveForInput() then
			if self.autoOpenClose == false and InputBinding.hasEvent(InputBinding.TOGGLE_COVER) then
				if self:getIsToggleCoverAllowed(not self.isCoverOpen) then
						self:setCoverState(not self.isCoverOpen);
				end;
			end;
		end;
	end;
end;

function animalCover:isAnyUnitFilled()
	if self.getFillLevel ~= nil then
		return self:getFillLevel() > 0
	end;
	return false
end;

function animalCover:draw()
	if self.autoOpenClose ~= false then
		else
		if self.isClient and self:getIsActiveForInput(true) then
			if self.coverAnimation ~= nil and self:getIsToggleCoverAllowed(not self.isCoverOpen) then
				if self.isCoverOpen then
					g_currentMission:addHelpButtonText(g_i18n:getText("action_closeanimalCover"), InputBinding.TOGGLE_COVER, nil, GS_PRIO_NORMAL);
				else                                                                                                  
					g_currentMission:addHelpButtonText(g_i18n:getText("action_openanimalCover"), InputBinding.TOGGLE_COVER, nil, GS_PRIO_NORMAL);
				end;
            end;
        end;
    end;
end;

function animalCover:getIsToggleCoverAllowed(isCoverOpen)
    if self.tipState ~= nil then
        return self.tipState == Trailer.TIPSTATE_CLOSED;
    end;
    return true;
end;

function animalCover:allowFillType(superFunc, fillType, allowEmptying)
    if not self.isCoverOpen then
        return false;
    end;
    if superFunc ~= nil then
        return superFunc(self, fillType, allowEmptying);
    end;
    return true;
end;

function animalCover:setCoverState(isOpen, noEventSend)
    if self.coverAnimation ~= nil then
        SetCoverStateEvent.sendEvent(self, isOpen, noEventSend);
        self.isCoverOpen = isOpen;
        if isOpen then
            self:playAnimation(self.coverAnimation, -1, self:getAnimationTime(self.coverAnimation), true);
        else
            self:playAnimation(self.coverAnimation, 1, self:getAnimationTime(self.coverAnimation), true);
        end;
    end;
end;

function animalCover:getAllowFillFromAir(superFunc)
    if not self.isCoverOpen then
        return false;
    end;
    if superFunc ~= nil then
        return superFunc(self);
    end;
    return true
end;

--[[
function animalCover:addFillTrigger(superFunc, trigger)
    if superFunc ~= nil then
        superFunc(self, trigger);
    end;
    if self.fillTriggers ~= nil and table.getn(self.fillTriggers) > 0 then
        self:setCoverState(true);
    end;
end;

function animalCover:removeFillTrigger(superFunc, trigger)
    if superFunc ~= nil then
        superFunc(self, trigger);
    end;
    if self.fillTriggers ~= nil and table.getn(self.fillTriggers) == 0 then
        self:setCoverState(false);
    end;
end;

function animalCover:onStartTip(tipTrigger, tipReferencePointIndex, noEventSend)
    if self.coverAnimation ~= nil then
        if self.forceOpenOnTip then
           self:setCoverState(true, true);
        end;
    end;
end;

]]

function animalCover:mouseEvent(posX, posY, isDown, isUp, button)
end;

function animalCover:keyEvent(unicode, sym, modifier, isDown)
end;

function animalCover:delete()
end;